# Class: mailscanner
#
#
class mailscanner {
    include exim
    include cron
    include clamav
    include spamassassin

    $clam_user = $operatingsystem ? {
        /(?i:Debian|Ubuntu)/ => "clamav",
        default => "clam",
    }
    package { "mailscanner":
        ensure => installed,
        require => Package["mailscanner-perl-deps"],
    }
    
    package { "baruwa-mailscanner":
        ensure => installed,
        require => Package["baruwa"],
    }

    package {"mailscanner-perl-deps":
        name => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => ["libmail-spf-perl", "libencode-detect-perl",
                        "libnet-cidr-lite-perl", "libio-string-perl", "libpod-simple-perl",
                        "libnet-dns-resolver-programmable-perl", "libparse-recdescent-perl",
                        "libmail-dkim-perl", "libinline-perl", "libnet-ip-perl", "antiword",
                        "libconvert-tnef-perl", "libdbd-pg-perl", "libdbd-mysql-perl", "unrar"],
            default => ["perl-Mail-SPF", "perl-Encode-Detect", "perl-Net-CIDR-Lite",
                        "perl-IO-String", "perl-Pod-Escapes", "perl-Pod-Simple",
                        "perl-Net-DNS-Resolver-Programmable", "perl-Parse-RecDescent",
                        "perl-Mail-DKIM", "perl-Inline", "perl-Net-IP", "antiword",
                        "perl-Convert-TNEF", "perl-DBD-Pg", "perl-DBD-MySQL", "unrar"],
        },
        ensure => installed,
    }

    service { "mailscanner":
        enable => true,
        ensure => running,
        hasrestart  => true,
        hasstatus => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => false,
            default => true,
        },
        pattern => 'MailScanner: waiting for messages',
        require => [Package["mailscanner"], Package["baruwa-mailscanner"], File["exim_out.conf"], Service["exim"]],
        subscribe => [File["exim.conf"], File["exim_out.conf"], File["macros.conf"]],
    }

    exec { "import-german-gpg-key":
        command => "sa-update --import /etc/mail/spamassassin/channel.d/german.conf",
        path => "/usr/bin:/usr/sbin:/bin",
        unless => "gpg --home /etc/mail/spamassassin/sa-update-keys --list-keys | grep 40F74481 &>/dev/null",
        require => [Package["mailscanner"], Package["spamassassin"]],
    }

    file { "/etc/MailScanner/MailScanner.conf":
        content => template("mailscanner/MailScanner.conf.erb"),
        require => Package["mailscanner"],
        notify => Service["mailscanner"],
    }

    file { "/etc/MailScanner/spam.assassin.prefs.conf":
        ensure  => present,
        mode    => "0644",
        owner   => "root",
        group   => "root",
        require => Package["mailscanner"],
        notify => Service["mailscanner"],
        content => template("mailscanner/spam.assassin.prefs.conf.erb"),
    }

    file { "/etc/mail/spamassassin/local.cf":
        target => "/etc/MailScanner/spam.assassin.prefs.conf",
        require => [File["/etc/MailScanner/spam.assassin.prefs.conf"], Package["spamassassin"]],
        ensure => link,
    }

    file { "filename.rules":
        mode    => "0644",
        owner   => "root",
        group   => "root",
        require => Package["mailscanner"],
        content => template("mailscanner/filename.rules"),
        notify  => Service["mailscanner"],
        path    => "/etc/MailScanner/rules/filename.rules",
    }

    file { "filetype.rules":
        mode    => "0644",
        owner   => "root",
        group   => "root",
        require => Package["mailscanner"],
        content => template("mailscanner/filetype.rules"),
        notify  => Service["mailscanner"],
        path    => "/etc/MailScanner/rules/filetype.rules",
    }

    file { "nonspam.actions.rules":
        mode => "0644",
        owner => "root",
        group => "root",
        require => Package["mailscanner"],
        content => template("mailscanner/nonspam.rules"),
        notify  => Service["mailscanner"],
        path    => "/etc/MailScanner/rules/nonspam.actions.rules",
    }

    exec { "fix-baruwa-phishing":
        command => "mv -f /etc/mail/spamassassin/baruwa.phishing.cf.rpmnew /etc/mail/spamassassin/baruwa.phishing.cf",
        unless => "grep 'BaruwaSAPhishingChecks /usr/share/' /etc/mail/spamassassin/baruwa.phishing.cf",
        notify => Service["mailscanner"],
    }

    exec { "fix-baruwa-sudo":
        command => 'sed -i -e \'$a\\\' /etc/sudoers.d/baruwa',
        unless => "tail -c1 /etc/sudoers.d/baruwa | read -r _",
        require => Package["baruwa-mailscanner"],
    }
}
