# Class: postgres
#
#
class postgresql {
    package { "postgresql":
        name => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => "postgresql-client-9.1",
            default => "postgresql",
        },
        ensure => installed,
    }
}

# Define: executesql
# Parameters:
# $username, $password, $database, $sql, $sqlcheck
#
define postgresql::executesql ($username, $password, $database, $sql, $sqlcheck) {
    if $baruwa_pgsql_host == '127.0.0.1' {
        exec { "runsql-${name}":
            command => "psql --username=${username} ${database} -c \"${sql}\" >> /dev/null 2>&1 && /bin/sleep 5",
            unless => "psql -U $username $database -c $sqlcheck",
            require => Service["postgresql"],
            environment => "PGPASSWORD=${password}",
		    timeout => 600,
		}
    } else {
        exec { "runsql-${name}":
            command => "psql --host=${baruwa_pgsql_host} -p $baruwa_pgsql_port --username=${username} ${database} -c \"${sql}\" >> /dev/null 2>&1 && /bin/sleep 5",
            unless => "psql -h ${baruwa_pgsql_host} -p $baruwa_pgsql_port -U $username $database -c $sqlcheck",
            environment => "PGPASSWORD=${password}",
		    timeout => 600,
		}
    }
}

# Define: createuser
# Parameters:
# $passwd
#
define postgresql::createuser ($username, $passwd) {
    if $baruwa_pgsql_host == '127.0.0.1' {
        executesql { "createuser-${name}":
    		password => $pgsql_password,
    	    username => "postgres",
    	    database => "postgres",
    	    sql => "CREATE ROLE ${username} WITH LOGIN PASSWORD '${passwd}';",
    	    sqlcheck => "\"SELECT usename FROM pg_user WHERE usename = '${username}'\" | grep ${username}",
    	    require => Service["postgresql"],
    	}
    } else {
        executesql { "createuser-${name}":
    		password => $pgsql_password,
    	    username => "postgres",
    	    database => "postgres",
    	    sql => "CREATE ROLE ${username} WITH LOGIN PASSWORD '${passwd}';",
    	    sqlcheck => "\"SELECT usename FROM pg_user WHERE usename = '${username}'\" | grep ${username}",
    	}
    }
}

# Define: createdb
# Parameters:
# $db, $owner
#
define postgresql::createdb ($database, $owner) {
    if $baruwa_pgsql_host == '127.0.0.1' {
        executesql { "createdb-${name}":
    		password => $pgsql_password,
    	    username => "postgres",
    	    database => "postgres",
    	    sql => "CREATE DATABASE ${database} WITH OWNER = ${owner} ENCODING = 'UTF8' TEMPLATE template0;",
    	    sqlcheck => "\"SELECT datname FROM pg_database WHERE datname ='${database}'\" | grep ${database}",
    	    require => Service["postgresql"],
    	}
    } else {
        executesql { "createdb-${name}":
    		password => $pgsql_password,
    	    username => "postgres",
    	    database => "postgres",
    	    sql => "CREATE DATABASE ${database} WITH OWNER = ${owner} ENCODING = 'UTF8' TEMPLATE template0;",
    	    sqlcheck => "\"SELECT datname FROM pg_database WHERE datname ='${database}'\" | grep ${database}",
    	}
    }
}

# Define: postgresql::createlang
# Parameters:
# arguments
#
define postgresql::createlang ($language, $database) {
    if $baruwa_pgsql_host == '127.0.0.1' {
        executesql { "createlang-${name}":
    		password => $pgsql_password,
    	    username => "postgres",
    	    database => $database,
    		sql => "CREATE LANGUAGE ${language};",
    	    sqlcheck => "\"SELECT lanname FROM pg_language WHERE lanname='${language}'\" | grep ${language}",
    	    require => Service["postgresql"],
    	}
    } else {
        executesql { "createlang-${name}":
    		password => $pgsql_password,
    	    username => "postgres",
    	    database => $database,
    		sql => "CREATE LANGUAGE ${language};",
    	    sqlcheck => "\"SELECT lanname FROM pg_language WHERE lanname='${language}'\" | grep ${language}",
    	}
    }
}
