# Class: spamassassin
#
#
class spamassassin {
    $sa_version = 3.003001
    package { "spamassassin":
        ensure => installed,
    }

    package { "wget":
        ensure => installed,
    }

    package { "perl-IP-Country":
        name => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => "libip-country-perl",
            default => "perl-IP-Country",
        },
        ensure => installed,
    }

    package { "spamassassin-plugin-iXhash":
        name => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => "spamassassin-plugin-ixhash",
            default => "spamassassin-plugin-iXhash",
        },
        ensure => installed,
        require => Package["spamassassin"],
    }

    package { "spamassassin-plugin-DecodeShortURLs":
        name => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => "spamassassin-plugin-decodeshorturls",
            default => "spamassassin-plugin-DecodeShortURLs",
        },
        ensure => installed,
        require => Package["spamassassin"],
    }

    package { ["re2c", "gcc", "make"]:
        ensure => installed,
        require => Package["spamassassin"],
    }

    service { "spamassassin":
        ensure => stopped,
        enable => false,
        hasstatus  => true,
        require => $operatingsystem ? {
            /(?i:Debian|Ubuntu)/ => File["/etc/default/spamassassin"],
            default => Package["spamassassin"],
        },
    }

    file { "/etc/cron.daily/malwarepatrol.sh":
        mode    => "0755",
        owner   => root,
        group   => mail,
        content => template("spamassassin/malwarepatrol.sh.erb"),
        ensure  => present,
        require => Package[wget],
    }

    file { "/etc/cron.daily/KAM.cf.sh":
        ensure => absent,
    }

    file { "baruwa-phishing.pm":
        mode    => "0644",
        owner   => "root",
        group   => "root",
        require => Package["spamassassin"],
        path => "/etc/mail/spamassassin/BaruwaSAPhishingChecks.pm",
        ensure => absent,
    }

    $v310file = "/etc/mail/spamassassin/v310.pre"
    $v320file = "/etc/mail/spamassassin/v320.pre"

    exec { "enable-awl":
        command     => "sed -i -e \"s/^#loadplugin Mail::SpamAssassin::Plugin::AWL/loadplugin Mail::SpamAssassin::Plugin::AWL/\" $v310file",
        path        => "/bin",
        require     => Package["spamassassin"],
        unless      => "grep '^loadplugin Mail::SpamAssassin::Plugin::AWL' $v310file",
    }

    exec { "enable-re2c":
        command     => "sed -i -e \"s/^# loadplugin Mail::SpamAssassin::Plugin::Rule2XSBody/loadplugin Mail::SpamAssassin::Plugin::Rule2XSBody/\" $v320file",
        path        => "/bin",
        require     => [Package["spamassassin"], Package["re2c", "gcc"]],
        unless      => "grep '^loadplugin Mail::SpamAssassin::Plugin::Rule2XSBody' $v320file",    
    }

    exec { "enable-shortcircuit":
        command     => "sed -i -e \"s/^# loadplugin Mail::SpamAssassin::Plugin::Shortcircuit/loadplugin Mail::SpamAssassin::Plugin::Shortcircuit/\" $v320file",
        path        => "/bin",
        require     => Package["spamassassin"],
        unless      => "grep '^loadplugin Mail::SpamAssassin::Plugin::Shortcircuit' $v320file",
    }

    $initfile = "/etc/mail/spamassassin/init.pre"
    exec { "enable-relay-country":
        command => "sed -i -e \"s/# loadplugin Mail::SpamAssassin::Plugin::RelayCountry/loadplugin Mail::SpamAssassin::Plugin::RelayCountry/\" $initfile",
        path => "/bin",
        require => [Package["spamassassin"], Package["perl-IP-Country"]],
        unless => "grep '^loadplugin Mail::SpamAssassin::Plugin::RelayCountry' $initfile",
    }

    exec { "import-sa-gpg-key":
        command => "sa-update --import /etc/mail/spamassassin/channel.d/spamassassin-official.conf",
        path => "/usr/bin:/usr/sbin:/bin",
        unless => "gpg --home /etc/mail/spamassassin/sa-update-keys --list-keys | grep 5244EC45 &>/dev/null",
        require => Package["spamassassin"],
    }

    exec { "import-sought-gpg-key":
        command => "sa-update --import /etc/mail/spamassassin/channel.d/sought.conf",
        path => "/usr/bin:/usr/sbin:/bin",
        unless => "gpg --home /etc/mail/spamassassin/sa-update-keys --list-keys | grep 6C6191E3 &>/dev/null",
        require => Exec["import-sa-gpg-key"],
    }

    exec { "initial-sa-update":
        command => "sa-update --gpgkey 6C6191E3 --channel sought.rules.yerp.org --channel updates.spamassassin.org",
        path => "/usr/bin:/usr/sbin:/bin",
        unless => "ls /var/lib/spamassassin/${sa_version}/updates_spamassassin_org.cf",
        require => Exec["import-sought-gpg-key"],
    }

    exec { "initial-sa-compile":
        command => "sa-compile",
        path => "/usr/bin:/usr/sbin:/bin",
        unless => "ls /var/lib/spamassassin/compiled",
        require => [Exec["initial-sa-update"], Package["re2c"]],
    }

    if $operatingsystem in ['Ubuntu', 'Debian'] {
        file { "/etc/default/spamassassin":
            ensure  => present,
            mode    => "0644",
            owner   => "root",
            group   => "root",
            content => template("spamassassin/spamassassin.erb"),
            require => Package["spamassassin"],
        }
    }

    if $baruwa_pgsql_host == '127.0.0.1' {
        include spamassassin::bayes
	    include spamassassin::awl
	    include spamassassin::grants
	}

    if $spamassassin_snf_enable == 'true' {
        include spamassassin::snf
    }
}
